# Welcome to run-logger

A"run" is a long-running process that depends on a set of parameters and outputs results in the form of logs.
This library has three primary functions:

1. Storing run logs in a database.
2. Storing metadata associated with each run in a database (e.g. for the purposes of reproducibility).
3. Managing parameters.

# Installation

```bash
pip install run-logger
```

# [Documentation](https://run-logger.readthedocs.io/en/latest/index.html)
